# Copyright (C) 2007, 2008 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Packager that builds KDE-PIM debian packages from the enterprise35 branch.
"""

import os
import time
import re

import treepkg.util
import treepkg.packager


class SourcePackager(treepkg.packager.SourcePackager):

    pkg_basename = "kdepim"

    def __init__(self, *args, **kw):
        super(SourcePackager, self).__init__(*args, **kw)
        self.enterprise_version = (time.strftime("%Y%m%d", time.localtime()) \
                                   + "." + str(self.revision))

    def determine_package_version(self, directory):
        enterprise_version = self.enterprise_version
        return self.track.version_template % locals()

    def update_version_numbers(self, pkgbasedir):
        """Overrides the inherited method to update version numbers in the code
        """
        versionstring = "(enterprise4 %s)" % self.enterprise_version
        failed = []
        for versionfile in ["kaddressbook/kabcore.cpp",
                            "kmail/kmversion.h",
                            "kontact/src/main.cpp",
                            "korganizer/version.h"]:
            if not treepkg.util.replace_in_file(os.path.join(pkgbasedir,
                                                             versionfile),
                                                "\(enterprise4 ([^)]*)\)",
                                                versionstring):
                failed.append(versionfile)
        if failed:
            raise RuntimeError("kdepim: failed to update version numbers in %s"
                               % (", ".join(failed),))

    def do_package(self):
        pkgbaseversion, pkgbasedir = self.export_sources()
        self.update_version_numbers(pkgbasedir)

        pkgbasename = "kdepim_" + pkgbaseversion
        origtargz = os.path.join(self.work_dir,
                                 pkgbasename + ".orig.tar.gz")
        self.create_tarball(origtargz, self.work_dir,
                            os.path.basename(pkgbasedir))

        changemsg = ("Update to SVN enterprise35 branch rev. %d"
                     % (self.revision,))
        self.copy_debian_directory(pkgbasedir, pkgbaseversion,
                                   changemsg)

        self.create_source_package(pkgbasedir, origtargz)
        self.move_source_package(pkgbasename)


class RevisionPackager(treepkg.packager.RevisionPackager):

    source_packager_cls = SourcePackager


class PackageTrack(treepkg.packager.PackageTrack):

    extra_config_desc = ["version_template"]

    revision_packager_cls = RevisionPackager

    def __init__(self, *args, **kw):
        self.version_template = kw.pop("version_template")
        super(PackageTrack, self).__init__(*args, **kw)
